@@ -66,11 +66,12 @@ class Client():
         :param readback: Flag to specify to check if write to registers was
             successful, defaults to False.
         :type readback: bool, optional
+        :raises ValueError: Raises if there is a problem with the config
         """
         if config is None:
             self.logger.error("Provide a configuration dictionary to set")
             raise ValueError("No configuration provided to set")
-        elif len(list(config.keys())) == 0:
+        elif config == {}:
             self.logger.error("Configuration dictionary empty")
             raise ValueError("Configuration dictionary empty")
         message = self._serialize('set', config, readback)
@@ -85,6 +86,8 @@ class Client():
         :type config: dict, optional
         :return: Dictionary containing ROC register values as read from cache
         :rtype: dict
+        :raises ValueError: Raises from _execute_transaction if server
+            responds with an error
         """
         if config is None:
             if self.description is None:
@@ -103,6 +106,8 @@ class Client():
     def describe(self):
         """
         Returns a description of the board with parameter min and max values
+        :raises ValueError: Raises from _execute_transaction if server
+            responds with an error
         """
         if self.description is None:
             self.description = self._execute_transaction({'type': 'describe',
@@ -115,6 +120,8 @@ class Client():
         """
         Resets The ROC ASICs of the Hexaboard and sets the cache to
         default values.
+        :raises ValueError: Raises from _execute_transaction if server
+            responds with an error
         """
         message = self._serialize('reset', {}, False)
         self._execute_transaction(message)
